==> haskell-wreq-0.5.2.1-33-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wreq
version: 0.5.2.1
id: wreq-0.5.2.1-FjEise5tcVI6vIyAGOdb6f
key: wreq-0.5.2.1-FjEise5tcVI6vIyAGOdb6f
license: BSD-3-Clause
copyright: 2014 Bryan O'\''Sullivan
maintainer: bos@serpentine.com
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/wreq
synopsis: An easy-to-use HTTP client library.
description:
    .
    A web client library that is designed for ease of use.
    .
    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>
    .
    Features include:
    .
    * Simple but powerful `lens`-based API
    .
    * A solid test suite, and built on reliable libraries like
    http-client and lens
    .
    * Session handling includes connection keep-alive and pooling, and
    cookie persistence
    .
    * Automatic response body decompression
    .
    * Powerful multipart form and file upload handling
    .
    * Support for JSON requests and responses, including navigation of
    schema-less responses
    .
    * Basic and OAuth2 bearer authentication
    .
    * Early TLS support via the tls package
category: Web
abi: 2d7a08e15990fec578f0ce17c03d5dde
exposed: True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types
hidden-modules: Network.Wreq.Internal Network.Wreq.Internal.AWS
                Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
                Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
                Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq
import-dirs: /usr/lib/ghc-8.4.3/site-local/wreq-0.5.2.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/wreq-0.5.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/wreq-0.5.2.1
hs-libraries: HSwreq-0.5.2.1-FjEise5tcVI6vIyAGOdb6f
depends:
    psqueues-0.2.7.0-KMUBd6ptzL99e2685MpIN7
    aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y
    attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ
    authenticate-oauth-1.6-1XlU2AbKd7ksYuLNmrpOi base-4.11.1.0
    base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    containers-0.5.11.0 cryptonite-0.25-90uxV0bWEYmfC6QouwM7s
    exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO ghc-prim-0.5.2.0
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    http-client-0.5.13.1-B8ymBgXYvEy5Ee96ZIFRim
    http-client-tls-0.3.5.3-DICwM9bpjP9DfjTwEdO1Cl
    http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc
    lens-4.16.1-Lbt16M482ky7VAhdoH5BdO
    lens-aeson-1.0.2-21Fe2TiEsw22MkvINulPdE
    memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi
    mime-types-0.1.0.8-9tF87HO5ShrGIShG8eldW4
    time-locale-compat-0.1.1.4-7wM80GF7eQsF3fUTGOdEvb
    template-haskell-2.13.0.0 text-1.2.3.0 time-1.8.0.2
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
abi-depends: psqueues-0.2.7.0-KMUBd6ptzL99e2685MpIN7=b704bba46afedd21ad44f62b1d1682a8
             aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y=07d229e9fe1ca7309e20349a237239ed
             attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ=d12eb845c076ee59608410c1ed86a159
             authenticate-oauth-1.6-1XlU2AbKd7ksYuLNmrpOi=ce5ca2d51dd8f9143024c9e8eafe3607
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh=0cc0842c69ffec2c0f1c4a27d1f518e1
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             cryptonite-0.25-90uxV0bWEYmfC6QouwM7s=ab6703e009204c8918b02064ccbf4d84
             exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO=87ba3c1011ac70bcfb17ce2e39a2e1bb
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             http-client-0.5.13.1-B8ymBgXYvEy5Ee96ZIFRim=9012795347b01804c5abe898411d88c8
             http-client-tls-0.3.5.3-DICwM9bpjP9DfjTwEdO1Cl=46cab2af4061ff0caf553ea44e1db7be
             http-types-0.12.1-K1Di4IDpOnPEbRIeR3j5Gc=48aca1d059bd297a17f6a458e8d85d56
             lens-4.16.1-Lbt16M482ky7VAhdoH5BdO=e1de6ba4869fc28b6d3f9faac9ec1cc8
             lens-aeson-1.0.2-21Fe2TiEsw22MkvINulPdE=8b4f52630d120efc2ed83932c7a873f5
             memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi=463ac0313409de6dd760baee29e5aba2
             mime-types-0.1.0.8-9tF87HO5ShrGIShG8eldW4=6260d9a08ca2b5415d71a41584891d7f
             time-locale-compat-0.1.1.4-7wM80GF7eQsF3fUTGOdEvb=f41790414214237de89461384d016ee3
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
haddock-interfaces: /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html: /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wreq-0.5.2.1-45-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wreq
version: 0.5.2.1
id: wreq-0.5.2.1-92dNnE7wgTdAelkxkaIEQt
key: wreq-0.5.2.1-92dNnE7wgTdAelkxkaIEQt
license: BSD-3-Clause
copyright: 2014 Bryan O'\''Sullivan
maintainer: bos@serpentine.com
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/wreq
synopsis: An easy-to-use HTTP client library.
description:
    .
    A web client library that is designed for ease of use.
    .
    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>
    .
    Features include:
    .
    * Simple but powerful `lens`-based API
    .
    * A solid test suite, and built on reliable libraries like
    http-client and lens
    .
    * Session handling includes connection keep-alive and pooling, and
    cookie persistence
    .
    * Automatic response body decompression
    .
    * Powerful multipart form and file upload handling
    .
    * Support for JSON requests and responses, including navigation of
    schema-less responses
    .
    * Basic and OAuth2 bearer authentication
    .
    * Early TLS support via the tls package
category: Web
abi: 6a77755519e0274f66f13c0a38e05963
exposed: True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types
hidden-modules: Network.Wreq.Internal Network.Wreq.Internal.AWS
                Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
                Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
                Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq
import-dirs: /usr/lib/ghc-8.4.3/site-local/wreq-0.5.2.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/wreq-0.5.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/wreq-0.5.2.1
hs-libraries: HSwreq-0.5.2.1-92dNnE7wgTdAelkxkaIEQt
depends:
    psqueues-0.2.7.0-KMUBd6ptzL99e2685MpIN7
    aeson-1.3.1.1-5HUAx09wxP9QY0dgM2orK
    attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ
    authenticate-oauth-1.6-FnFPJLnxQtlB2dhBQsTNGv base-4.11.1.0
    base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    containers-0.5.11.0 cryptonite-0.25-Ka20h0HuI7x3L9WMrwHuzr
    exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO ghc-prim-0.5.2.0
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    http-client-0.5.13.1-JQycBjVP1w6IpdxQNtWm0J
    http-client-tls-0.3.5.3-ZfxwMGQ6gFCFAY5tb037r
    http-types-0.12.1-BL2DF5CyOaZENPHytlMY2x
    lens-4.17-136TtowFHoqEYCGwhzMJxH
    lens-aeson-1.0.2-4RNsS92Kq646cJ7NUMGyqv
    memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk
    mime-types-0.1.0.8-9tF87HO5ShrGIShG8eldW4
    time-locale-compat-0.1.1.4-7wM80GF7eQsF3fUTGOdEvb
    template-haskell-2.13.0.0 text-1.2.3.0 time-1.8.0.2
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
abi-depends: psqueues-0.2.7.0-KMUBd6ptzL99e2685MpIN7=b704bba46afedd21ad44f62b1d1682a8
             aeson-1.3.1.1-5HUAx09wxP9QY0dgM2orK=a4f854631dd0eec57df5f1d1976bd18b
             attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ=d12eb845c076ee59608410c1ed86a159
             authenticate-oauth-1.6-FnFPJLnxQtlB2dhBQsTNGv=43f40c9b97fae95ffb6aa0215afbe814
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh=0cc0842c69ffec2c0f1c4a27d1f518e1
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             cryptonite-0.25-Ka20h0HuI7x3L9WMrwHuzr=049bf293d9c1bef7bdb45e8c7d818d0c
             exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO=87ba3c1011ac70bcfb17ce2e39a2e1bb
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             http-client-0.5.13.1-JQycBjVP1w6IpdxQNtWm0J=47e6e7c158fcbac63448de8f552825d4
             http-client-tls-0.3.5.3-ZfxwMGQ6gFCFAY5tb037r=c51017920c12224dc5f50e3d36cece0a
             http-types-0.12.1-BL2DF5CyOaZENPHytlMY2x=aadbe1e05b8515b9eaaa1fc6b4b17f18
             lens-4.17-136TtowFHoqEYCGwhzMJxH=af0333f9835406408f489187753fa79b
             lens-aeson-1.0.2-4RNsS92Kq646cJ7NUMGyqv=14a50a01570a6fc1d48a108ee91d66da
             memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk=23a2e2ee61129c4073d4aeb70df9c169
             mime-types-0.1.0.8-9tF87HO5ShrGIShG8eldW4=6260d9a08ca2b5415d71a41584891d7f
             time-locale-compat-0.1.1.4-7wM80GF7eQsF3fUTGOdEvb=f41790414214237de89461384d016ee3
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
haddock-interfaces: /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html: /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
